Fabsible
========

Fabsible is ansible framework which is object-oriented.

Init
----

To init new project, type `fabsible-init -i <inventory_file>` to init new project

Configuration
-------------

TODO

Mostly typical ansible configuration


Run
---

`fabsible-play`
